
%function [comp, Type, nodenames] = parse(filename); 
% read each line of the file into a cell array
% skip comment lines (Matlab style comments)
file = textread(filename,'%s','delimiter','\n','commentstyle','matlab');
% n is the number of lines in the file.
% The length of each line is stored in line[]
n = size(file,1);
line = zeros(n,1);
for k=1:n
    line(k) = size(char(file(k)),2);
end
% remove blank lines
%idx = find(line>0);
%file = file(idx);
file = file(line>0);

% clear temporary variables
clear k n idx line;

% parse the non-blank lines of the file
n = size(file,1);
Type = cell(n,1);
comp = struct('type',{},'name',{},'value',{},'nodenames',{},'node',{});
for k=1:n
    str = char(file(k));
    t = strread(str,'%s');
    Type(k) = t(1);
    ctype = char(t(1));
    comp(k).type = ctype;
    clear node;
    switch upper(ctype)
        case {'R','C','L','I','V','D'}
            node=t(3:4);
            value = char(t(5));
        case {'E','F','G'}
            node=t(3:6);
            value = char(t(7));
        case { 'OA' }
            node = t(3:5);
            value = '0';
        case { 'PROBE' }
            comp(k).value = char(t(2:length(t)));
            continue;
        otherwise
            continue;
    end
    comp(k).name = char(t(2));
    comp(k).value = parse_number(value);
    comp(k).nodenames = node;
end

% compile an ordered list of unique nodenames
clear unique_nodes;
unique_nodes = comp(1).nodenames;
for k=2:n
    unique_nodes = union(unique_nodes,comp(k).nodenames);
end

% Remove 0 (ground reference) from list of unique nodenames
nodenames = setdiff(unique_nodes,'0');

% assign node numbers to node names
for k=1:n
    mynodes = comp(k).nodenames;
    m=length(mynodes);
    for jm=1:m
        idx = find(strcmp(nodenames,mynodes(jm)));
        if (idx)
            comp(k).node(jm)=idx;
        else
            comp(k).node(jm)=0;
        end
    end
end

% clear temporary variables
clear mynodes file k jm n m idx unique_nodes str value node t ctype;

