%% build a symbolic circuit system

% count the number of nodes
nbr_nodes = length(nodenames);

% count the number of voltage sources
idv = find(strcmp(Type,'V'))';
idl = find(strcmp(Type,'L'))';
ide = find(strcmp(Type,'E'))';
idf = find(strcmp(Type,'F'))';
idoa = find(strcmp(Type,'OA'))';
nrows = nbr_nodes + length(idv) + length(idl)+ length(ide) + length(idf) + length(idoa);

Gm = sym(zeros(nrows));
Cm =sym(zeros(nrows));
clear k;

% name the voltage nodes
yname = cell(nrows,1);
for k = 1:nbr_nodes
    yname(k) = cellstr(sprintf('V(%s)',char(nodenames(k))));
end


%Resistances
idr = find(strcmp(Type,'R'))';

% Remember: for a for loop the index is set to the columns of idr,
% so here idr must be a row vector.
for k = idr
    Node = comp(k).node;
    Gm = nmAcc(Node(1),Node(2),1/sym(comp(k).name),Gm);
end

%Capacitance
idc = find(strcmp(Type,'C'))';
for k = idc
    Node = comp(k).node;
    Cm = nmAcc(Node(1),Node(2),sym(comp(k).name),Cm);
end

% G Source (VCCS)
idg = find(strcmp(Type,'G'))';

for k=idg
    Node = comp(k).node;
    Gm = gmAcc(Node(1),Node(2),Node(3),Node(4),sym(comp(k).name),Gm);
end

% General current sources
idi = find(strcmp(Type,'I'))';

Is  = sym(zeros(nrows,1));
for k = idi
    Node = comp(k).node;
    Is=srcAcc(Node(1),Node(2),sym(comp(k).name),Is);
end

% General voltage sources
m = nbr_nodes;
for k = idv
    m = m + 1;
    Node = comp(k).node;
    Gm = mnaVsrc(m,Node(1),Node(2),Gm);
    Is(m) = sym(comp(k).name); % ??? Check on this
    % name the current node
    %str1 = char(nodenames(Node(1)));
    %str2 = char(nodenames(Node(2)));
    yname(m)=cellstr(sprintf('I(%s)',comp(k).name));
end

% Inductor
for k = idl
    m = m + 1;
    Node = comp(k).node;
    Gm = mnaVsrc(m,Node(1),Node(2),Gm);
    Cm(m,m) = -sym(comp(k).name);
end


% E Source (VCVS)
for k = ide
    m = m+1;
    Node = comp(k).node;
    Gm = mnaEsrc(m,Node(1),Node(2),Node(3),Node(4),sym(comp(k).name),Gm);
end

% F Source (CCVS)
for k = idf
    m = m+1;
    Node = comp(k).node;
    Gm = mnaFsrc(m,Node(1),Node(2),Node(3),Node(4),sym(comp(k).name),Gm);
end

% OA Source (ideal op-amp)
for k = idoa
    m = m+1;
    Node = comp(k).node;
    Gm = mnaOA(m,Node(1),Node(2),Node(3),Gm);
    %str1 = char(nodenames(Node(3)));
    yname(m) = cellstr(sprintf('I(%s)',comp(k).name));
end
%%
% clear temporary variables
clear k m n;
clear Node nrows nbr_nodes str1;
clear idc ide idf idg idi idl idoa idr idv;
